<?php
/*
 Plugin Name: Pollphin for Wordpress
 Plugin URI: http://wordpress.org/extend/plugins/wp-pollphin
 Description: Embed Pollphin polls without modifying your template code on every post or page to easily enable a user feedback opportunity!
 Version: 0.4
 Author: Monday Consulting
 Author URI: http://www.monday-consulting.com
 License: GPLv2 
 */

// define the custom style here
define('POLLPHIN_CUSTOM_CSS_FILE', 'pollphin-custom.css');
define('POLLPHIN_CUSTOM_CSS_NAME', 'pollphin custom');
define('POLLPHIN_CUSTOM_CSS_DEFAULT', '0');
// define the custom style here

define('POLLPHIN_PLUGIN_URL', plugin_dir_url(__FILE__));
define('POLLPHIN_PLUGIN_DIR', plugin_dir_path(__FILE__));

$styles = array(array('name' => 'pollphin default', 'value' => 1, 'file' => '', 'default' => POLLPHIN_CUSTOM_CSS_DEFAULT - 1), 
                array('name' => POLLPHIN_CUSTOM_CSS_NAME, 'value' => 2, 'file' => POLLPHIN_CUSTOM_CSS_FILE, 'default' => POLLPHIN_CUSTOM_CSS_DEFAULT));

$meta_box = array(
    'id' => 'pollphin_meta',
    'title' => 'WP-Pollphin',
    'context' => 'normal',
    'priority' => 'high',
    'fields' => array(
        array(
            'name' => '_pollphin_poll_id',
            'desc' => 'Pollphin poll ID',
            'id' => '_pollphin_poll_id',
            'type' => 'text',
            'std' => ''
        ),
        array(
            'name' => '_pollphin_style',
            'desc' => 'Pollphin style',
            'id' => '_pollphin_style',
            'type' => 'select',
            'options' => $styles
        )
     )
);

function read_styles() {
  $handle = opendir(POLLPHIN_PLUGIN_DIR.'styles');
  $files[] = array('name' => 'pollphin default', 'value' => '');
  while (false !== ($file = readdir($handle))) {
    if(end(explode(".",$file))=='css') {
      $files[] = array('name' => current(explode(".",$file)), 'value' => $file);
    }
  }  
  closedir($handle);
  return $files; 
}

add_action('add_meta_boxes', 'pollphin_meta_box_add');
// backwards compatible
add_action('admin_init', 'pollphin_meta_box_add', 1);

add_action('edit_post', 'pollphin_save_postdata');
add_action('publish_post', 'pollphin_save_postdata');
add_action('edit_page_form', 'pollphin_save_postdata');
add_action('save_post', 'pollphin_save_postdata');

add_filter('the_content', 'pollphin_frontend_data_add', 1);

add_action('wp_print_styles', 'add_stylesheet');

function pollphin_meta_box_add() {
	global $meta_box;
	
	add_meta_box($meta_box['id'], $meta_box['title'], 'pollphin_meta', 'page', $meta_box['context'], $meta_box['priority']);
	add_meta_box($meta_box['id'], $meta_box['title'], 'pollphin_meta', 'post', $meta_box['context'], $meta_box['priority']);
}

function pollphin_meta() {
  global $meta_box, $post;  
  
  wp_nonce_field(plugin_basename(__FILE__), 'pollphin_nonce');

  echo '<table>';
  foreach ($meta_box['fields'] as $field) {  
    $meta = get_post_meta($post->ID, $field['id'], true);
    echo '<tr>',
         '<th scope="row" style="text-align:left; width:120px;"><label for="', $field['id'], '">', $field['desc'], '</label></th>',
         '<td>';
    switch ($field['type']) {
      case 'text':
        echo '<input type="text" name="', $field['id'], '" id="', $field['id'], '" value="', $meta ? $meta : $field['std'], '" size="15" style="width: 150px;" />';
      break;
      case 'textarea':
        echo '<textarea name="', $field['id'], '" id="', $field['id'], '" cols="60" rows="4" style="width:97%">', $meta ? $meta : $field['std'], '</textarea>';
      break;
      case 'select':
        echo '<select name="', $field['id'], '" id="', $field['id'], '" style="width: 150px;">';
        foreach ($field['options'] as $option) {
          echo '<option', $meta == $option['value'] || (!$meta && $option['default'] > 0) ? ' selected="selected"' : '', ' value="', $option['value'], '"', '>', $option['name'], '</option>';
        }
        echo '</select>';
      break;
      case 'radio':
        foreach ($field['options'] as $option) {
          echo '<input type="radio" name="', $field['id'], '" value="', $option['value'], '"', $meta == $option['value'] ? ' checked="checked"' : '', ' />', $option['name'];
        }
      break;
      case 'checkbox':
        echo '<input type="checkbox" name="', $field['id'], '" id="', $field['id'], '"', $meta ? ' checked="checked"' : '', ' />';
      break;
    }
    echo '</td>',
         '</tr>';        
   }
   echo '<tr>',
        '<td>';
   echo '<input type="button" id="reset_pollphin_poll_id" name="reset_pollphin_poll_id" value="remove poll" size="15" onclick="javascript: document.getElementById(\'_pollphin_poll_id\').value=\'\'; document.getElementById(\'_pollphin_style\').options[document.getElementById(\'_pollphin_style\').selectedIndex].value=\'\'; return false;"/>';        
   echo '</td>',
        '</tr>';   
   echo '</table>';
}

function pollphin_save_postdata($post_id) {
	global $meta_box;
		
	if (!wp_verify_nonce( $_POST['pollphin_nonce'], plugin_basename(__FILE__))) {
		return $post_id;
	}

	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
		return $post_id;
	}
	
	if ('page' == $_POST['post_type']) {
		if (!current_user_can('edit_page', $post_id))
		return $post_id;
	}
	else {
		if (!current_user_can('edit_post', $post_id))
		return $post_id;
	}
	
  foreach ($meta_box['fields'] as $field) {
    $old = get_post_meta($post_id, $field['id'], true);
    $new = $_POST[$field['id']];
    if (!empty($new) && $new != $old) {    	   
    	if ($field['id'] === "_pollphin_poll_id") {
    		if (is_numeric($new) && $new > 0) {
          update_post_meta($post_id, $field['id'], $new);
    		}
    	}
    	else {
    		update_post_meta($post_id, $field['id'], $new);
    	}
    } 
    elseif (empty($new)) {
      delete_post_meta($post_id, $field['id'], $old);
    }
  }
}

function pollphin_frontend_data_add($content) {
	global $post;	
	
	$pollid = get_post_meta($post->ID, '_pollphin_poll_id', true);
	if (!is_front_page() && $pollid > 0) {			
		$pollphinStyle = "true";
		if(get_post_meta($post->ID, '_pollphin_style', true) > 1) {
				$pollphinStyle = "false";
		}
		$content .= "<script type='text/javascript'>".  
	  "var pollphinVars = {\n". 
	  "'pollid'       : ".$pollid.",\n". 
	  "'pollphinStyle': \"".$pollphinStyle."\"\n".  
	  "}\n".
	  "</script><script src='http://www.pollphin.de/pollphin/embedded/js/poll_pollphin.js' type='text/javascript'></script>";
	}
	return $content;	
}

function add_stylesheet() {
	global $post, $styles;

  $styleID = get_post_meta($post->ID, '_pollphin_style', true);
  if (!is_front_page() && $styleID > 1) {
    foreach ($styles as $style) {
    	if ($styleID == $style['value']) {
        wp_register_style($style['name'], POLLPHIN_PLUGIN_URL.'styles/'.$style['file'], array(), false);
        wp_enqueue_style($style['name']);
    	}
    }
  }
}

?>
